/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.jpa.classloader;

import java.util.HashMap;
import java.util.Hashtable;
import java.util.Map;

import javax.naming.Binding;
import javax.naming.Context;
import javax.naming.Name;
import javax.naming.NameClassPair;
import javax.naming.NameParser;
import javax.naming.NamingEnumeration;
import javax.naming.NamingException;
import javax.sql.DataSource;

/**
 * @author Brad Maxwell
 *
 */
public class MockContext implements Context
{
   private Map<String, Object> map = new HashMap<String, Object>();
   
   /* (non-Javadoc)
    * @see javax.naming.Context#lookup(javax.naming.Name)
    */
   public Object lookup(Name name) throws NamingException
   {
      return map.get(name.toString());
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#lookup(java.lang.String)
    */
   public Object lookup(String name) throws NamingException
   {
      return map.get(name);
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#bind(javax.naming.Name, java.lang.Object)
    */
   public void bind(Name name, Object obj) throws NamingException
   {
      map.put(name.toString(), obj);
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#bind(java.lang.String, java.lang.Object)
    */
   public void bind(String name, Object obj) throws NamingException
   {
      map.put(name, obj);
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#rebind(javax.naming.Name, java.lang.Object)
    */
   public void rebind(Name name, Object obj) throws NamingException
   {
      map.put(name.toString(), obj);
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#rebind(java.lang.String, java.lang.Object)
    */
   public void rebind(String name, Object obj) throws NamingException
   {
      map.put(name, obj);
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#unbind(javax.naming.Name)
    */
   public void unbind(Name name) throws NamingException
   {
      map.remove(name.toString());
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#unbind(java.lang.String)
    */
   public void unbind(String name) throws NamingException
   {
      map.remove(name);

   }

   /* (non-Javadoc)
    * @see javax.naming.Context#rename(javax.naming.Name, javax.naming.Name)
    */
   public void rename(Name oldName, Name newName) throws NamingException
   {
      throw new NamingException("Not implemented");
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#rename(java.lang.String, java.lang.String)
    */
   public void rename(String oldName, String newName) throws NamingException
   {
      throw new NamingException("Not implemented");
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#list(javax.naming.Name)
    */
   public NamingEnumeration<NameClassPair> list(Name name) throws NamingException
   {
      throw new NamingException("Not implemented");
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#list(java.lang.String)
    */
   public NamingEnumeration<NameClassPair> list(String name) throws NamingException
   {
      throw new NamingException("Not implemented");
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#listBindings(javax.naming.Name)
    */
   public NamingEnumeration<Binding> listBindings(Name name) throws NamingException
   {
      throw new NamingException("Not implemented");
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#listBindings(java.lang.String)
    */
   public NamingEnumeration<Binding> listBindings(String name) throws NamingException
   {
      throw new NamingException("Not implemented");
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#destroySubcontext(javax.naming.Name)
    */
   public void destroySubcontext(Name name) throws NamingException
   {
      throw new NamingException("Not implemented");
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#destroySubcontext(java.lang.String)
    */
   public void destroySubcontext(String name) throws NamingException
   {
      throw new NamingException("Not implemented");
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#createSubcontext(javax.naming.Name)
    */
   public Context createSubcontext(Name name) throws NamingException
   {
      throw new NamingException("Not implemented");
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#createSubcontext(java.lang.String)
    */
   public Context createSubcontext(String name) throws NamingException
   {
      throw new NamingException("Not implemented");
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#lookupLink(javax.naming.Name)
    */
   public Object lookupLink(Name name) throws NamingException
   {
      throw new NamingException("Not implemented");
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#lookupLink(java.lang.String)
    */
   public Object lookupLink(String name) throws NamingException
   {
      throw new NamingException("Not implemented");   
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#getNameParser(javax.naming.Name)
    */
   public NameParser getNameParser(Name name) throws NamingException
   {
      throw new NamingException("Not implemented");   
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#getNameParser(java.lang.String)
    */
   public NameParser getNameParser(String name) throws NamingException
   {
      throw new NamingException("Not implemented");   
    }

   /* (non-Javadoc)
    * @see javax.naming.Context#composeName(javax.naming.Name, javax.naming.Name)
    */
   public Name composeName(Name name, Name prefix) throws NamingException
   {
      throw new NamingException("Not implemented");   
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#composeName(java.lang.String, java.lang.String)
    */
   public String composeName(String name, String prefix) throws NamingException
   {
      throw new NamingException("Not implemented");   
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#addToEnvironment(java.lang.String, java.lang.Object)
    */
   public Object addToEnvironment(String propName, Object propVal) throws NamingException
   {
      throw new NamingException("Not implemented");   
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#removeFromEnvironment(java.lang.String)
    */
   public Object removeFromEnvironment(String propName) throws NamingException
   {
      throw new NamingException("Not implemented");   
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#getEnvironment()
    */
   public Hashtable<?, ?> getEnvironment() throws NamingException
   {
      throw new NamingException("Not implemented");
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#close()
    */
   public void close() throws NamingException
   {
      map.clear();
   }

   /* (non-Javadoc)
    * @see javax.naming.Context#getNameInNamespace()
    */
   public String getNameInNamespace() throws NamingException
   {
      throw new NamingException("Not implemented");
   }

}
